@@ -139,6 +139,7 @@ def fup_or_defup():
     """FUP customers in over-quota and DEFUP under quota"""
     LOGS.logger.info("Fup or defup customers -- START")
     yesterday = (dt.today() - timedelta(days=1)).strftime("%Y-%m-%d")
+    customers_errors = []
 
     customers_si = core.get_customers_si()
     for customer in customers_si:
@@ -151,12 +152,18 @@ def fup_or_defup():
             else:
                 core.defup_customer(customer_name)
         else:
-            operation = "get customer {} total consumption for {}".format(customer_name, yesterday)
-            LOGS.logger.error("Unable to {}. No history found.".format(operation))
-            core.send_error_report(
-                operation=operation,
-                error="No history found for that date"
-            )
+            core.defup_customer(customer_name)
+            customers_errors.append(customer_name)
+
+    if customers_errors:
+        LOGS.logger.error(
+            "No consumption history found for {} for the following customers: {}"
+            .format(yesterday, customers_errors)
+        )
+        core.send_error_report(
+            operation="get customers total consumption for {}".format(yesterday),
+            error="No history found for {}".format(customers_errors)
+        )
     LOGS.logger.info("Fup or defup customers -- END")
 
 
