@@ -494,7 +494,7 @@ def get_consommation_sum(customer, date):
         "FROM all_cdr "
         "WHERE clientname ilike '%{customer}%' "
         "AND sessiontime >= '{date}'::date "  # YYYY-MM-DD
-        "AND source='internet' "
+        "AND source IN ('internet','cache') "
         "AND (extract('ISODOW' FROM sessiontime) between 1 AND 5) "
         "AND extract(HOUR FROM sessiontime) < 19 "
         "AND extract(HOUR FROM sessiontime) > 8 "
